@@ -124,7 +124,7 @@ struct wbxmlScannerPriv_s
     Ret_t (*destroy)(XltDecScannerPtr_t);
     Ret_t (*pushTok)(XltDecScannerPtr_t);
     void (*setBuf)(XltDecScannerPtr_t pScanner, const MemPtr_t pBufStart, const MemPtr_t pBufEnd);
-    MemPtr_t (*getPos)(XltDecScannerPtr_t pScanner);
+    MemPtr_t (*getPos)(XltDecScannerPtr_t pScanner, Long_t *remaining);
 
     /* public attributes */
     XltDecTokenPtr_t curtok;       /**< current token */
@@ -168,7 +168,7 @@ static Ret_t _destroy(XltDecScannerPtr_t);
 static Ret_t _nextTok(XltDecScannerPtr_t);
 static Ret_t _pushTok(XltDecScannerPtr_t);
 static void _setBuf(XltDecScannerPtr_t, const MemPtr_t, const MemPtr_t);
-static MemPtr_t _getPos(XltDecScannerPtr_t);
+static MemPtr_t _getPos(XltDecScannerPtr_t, Long_t *remaining);
 
 /**
  * Advance the current position pointer after checking whether the end of
@@ -398,8 +398,10 @@ _setBuf(XltDecScannerPtr_t pScanner, const MemPtr_t pBufStart,
 }
 
 static MemPtr_t
-_getPos(XltDecScannerPtr_t pScanner)
+_getPos(XltDecScannerPtr_t pScanner, Long_t *remaining)
 {
+    if (remaining)
+      *remaining = ((wbxmlScannerPrivPtr_t)pScanner)->bufend - ((wbxmlScannerPrivPtr_t)pScanner)->pos;
     return ((wbxmlScannerPrivPtr_t)pScanner)->pos;
 }
 
