@@ -1,7 +1,7 @@
 /*
  *  File:         SuperDataStore.h
  *
- *  Author:			  Lukas Zeller (luz@plan44.ch)
+ *  Author:       Lukas Zeller (luz@plan44.ch)
  *
  *  TSuperDataStore
  *    "Virtual" datastore consisting of an union of other
@@ -111,7 +111,7 @@ public:
   virtual ~TSuperDataStore();
   virtual void dsResetDataStore(void) { InternalResetDataStore(); inherited::dsResetDataStore(); };
   // add links to subdatastores
-	void addSubDatastoreLink(TSubDSLinkConfig *aDSLinkConfigP, TLocalEngineDS *aDatastoreP);
+  void addSubDatastoreLink(TSubDSLinkConfig *aDSLinkConfigP, TLocalEngineDS *aDatastoreP);
   // abort
   virtual void engAbortDataStoreSync(TSyError aReason, bool aLocalProblem, bool aResumable=true);
   virtual bool isAborted(void); // test abort status
@@ -166,8 +166,13 @@ public:
 
   // Abstracts of TLocalEngineDS
 protected:
+  // check if all subdatastores can restart
+  bool canRestart();
   // obtain Sync Cap mask, must be lowest common mask of all subdatastores
   virtual uInt32 getSyncCapMask(void);
+  // intersection of all sync mode sets in the subdatastores
+  virtual bool syncModeSupported(const std::string &mode);
+  virtual void getSyncModes(set<string> &modes);
   // Internal events during sync for derived classes
   // Note: local DB authorisation must be established already before calling these
   // - prepares for Sync with this datastore
@@ -311,10 +316,10 @@ private:
   TSubDSLinkList::iterator fCurrentGenDSPos;
 }; // TSuperDataStore
 
-}	// namespace sysync
+} // namespace sysync
 
 #endif // SUPERDATASTORES
 
-#endif	// SuperDataStore_H
+#endif  // SuperDataStore_H
 
 // eof
