@@ -225,6 +225,8 @@ public:
   bool fShowCTCapProps;
   // default value for flag to send type/size in CTCap for SyncML 1.0 (disable as old clients like S55 crash on this)
   bool fShowTypeSzInCTCap10;
+  // flag to enable SyncEvolution-specific sync mode extensions in outgoing devInf.
+  bool fSyncModeExtensions;
   // default value for sending end date-only values (like DTEND) as last time unit of previous day (i.e. 23:59:59, inclusive)
   // instead of midnight of next day (exclusive, like in iCalendar 2.0)
   bool fVCal10EnddatesSameDay;
@@ -522,6 +524,10 @@ public:
   bool sessionMustContinue(void);
   virtual void essentialStatusReceived(void) { /* NOP here */ };
   void delayExecUntilNextRequest(TSmlCommand *aCommand);
+  bool onlyItemChangesPending();
+  bool onlySyncPending();
+  bool tryDelayedExecutionCommands(); // returns syncEndAfterSyncPackageEnd
+  bool executeDelayedCmd(TSmlCommand *aCmdP); // wrapper around TSmlCommand::execute() which issues queued Status commands if any are pending
   bool delayedSyncEndsPending(void) { return fDelayedExecSyncEnds>0; };
   // - continue interrupted or prevented issue in next package
   void ContinuePackageRoot(void);
@@ -899,6 +905,7 @@ protected:
   // - session state
   TPackageStates fIncomingState; // incoming package state
   TPackageStates fCmdIncomingState; // while executing commands: state when command was received (actual might be different due to queueing)
+  TSmlCommand *fCmdIncoming; // while executing command inside process(): command being processed
   TPackageStates fOutgoingState; // outgoing package state
   bool fRestarting; // Set to true in TSyncSession::processAlertItem() while processing the first Alert from a
                     // client which requests another sync cycle. Applies to all further Alerts, cleared
